==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageStreamSpecBuilder extends io.fabric8.openshift.api.model.ImageStreamSpecFluentImpl<io.fabric8.openshift.api.model.ImageStreamSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageStreamSpec,io.fabric8.openshift.api.model.ImageStreamSpecBuilder>{
  public ImageStreamSpecBuilder() {
    this(false);
  }
  public ImageStreamSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageStreamSpec(), validationEnabled);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageStreamSpec(), validationEnabled);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamSpec instance) {
    this(fluent, instance, false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDockerImageRepository(instance.getDockerImageRepository()); 
    fluent.withLookupPolicy(instance.getLookupPolicy()); 
    fluent.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpec instance) {
    this(instance,false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDockerImageRepository(instance.getDockerImageRepository()); 
    this.withLookupPolicy(instance.getLookupPolicy()); 
    this.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageStreamSpec build() {
    ImageStreamSpec buildable = new ImageStreamSpec(fluent.getDockerImageRepository(),fluent.getLookupPolicy(),fluent.getTags());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageStreamSpecBuilder that = (ImageStreamSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageStreamSpecBuilder extends io.fabric8.openshift.api.model.ImageStreamSpecFluentImpl<io.fabric8.openshift.api.model.ImageStreamSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageStreamSpec,io.fabric8.openshift.api.model.ImageStreamSpecBuilder>{
  public ImageStreamSpecBuilder() {
    this(false);
  }
  public ImageStreamSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageStreamSpec(), validationEnabled);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageStreamSpec(), validationEnabled);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamSpec instance) {
    this(fluent, instance, false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent,io.fabric8.openshift.api.model.ImageStreamSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDockerImageRepository(instance.getDockerImageRepository()); 
    fluent.withLookupPolicy(instance.getLookupPolicy()); 
    fluent.withTags(instance.getTags()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpec instance) {
    this(instance,false);
  }
  public ImageStreamSpecBuilder(io.fabric8.openshift.api.model.ImageStreamSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDockerImageRepository(instance.getDockerImageRepository()); 
    this.withLookupPolicy(instance.getLookupPolicy()); 
    this.withTags(instance.getTags()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageStreamSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageStreamSpec build() {
    ImageStreamSpec buildable = new ImageStreamSpec(fluent.getDockerImageRepository(),fluent.getLookupPolicy(),fluent.getTags());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageStreamSpecBuilder that = (ImageStreamSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
